Summary: Compat package with gnutls library ABI version 28
Name: compat-gnutls28
Version: 3.3.21
Release: 1%{?dist}
# The libraries are LGPLv2.1+, utilities are GPLv3+
License: LGPLv2+
Group: System Environment/Libraries
BuildRequires: p11-kit-devel >= 0.21.3, gettext-devel
BuildRequires: zlib-devel, readline-devel, libtasn1-devel >= 4.3
BuildRequires: libtool, automake, autoconf, texinfo
BuildRequires: autogen-libopts-devel >= 5.18 autogen
BuildRequires: nettle-devel >= 3.1.1
BuildRequires: trousers-devel >= 0.3.11.2
BuildRequires: libidn-devel
BuildRequires: gperf
Requires: crypto-policies >= 20151004
Requires: p11-kit-trust
Requires: libtasn1 >= 4.3

URL: http://www.gnutls.org/
# XXX patent tainted code removed.
Source0: gnutls-%{version}-hobbled.tar.xz
Source2: hobble-gnutls
Patch1: gnutls-3.2.7-rpath.patch
Patch3: gnutls-3.1.11-nosrp.patch
Patch4: gnutls-3.3.6-default-policy.patch

# Explicitly conflict with older gnutls packages that ship libraries
# with the same soname as this compat package
Conflicts: gnutls < 3.4

# Wildcard bundling exception https://fedorahosted.org/fpc/ticket/174
Provides: bundled(gnulib) = 20130424

%description
Compatibility package with gnutls library ABI version 28.

%prep
%setup -q -n gnutls-%{version}

%patch1 -p1 -b .rpath
%patch3 -p1 -b .nosrp
%patch4 -p1 -b .default-policy

sed 's/gnutls_srp.c//g' -i lib/Makefile.in
sed 's/gnutls_srp.lo//g' -i lib/Makefile.in
rm -f lib/minitasn1/*.c lib/minitasn1/*.h
rm -f src/libopts/*.c src/libopts/*.h src/libopts/compat/*.c src/libopts/compat/*.h 
sed -i -e 's|sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/lib /usr/lib %{_libdir}|g' configure

%{SOURCE2} -e

%build

autoreconf -fvi
# this overrides the -znow from hardened builds.
CFLAGS="$RPM_OPT_FLAGS -Wl,-z,lazy"
export CFLAGS

%configure --with-libtasn1-prefix=%{_prefix} \
           --with-included-libcfg \
           --disable-static \
           --disable-openssl-compatibility \
           --disable-srp-authentication \
	   --disable-non-suiteb-curves \
	   --with-system-priority-file=%{_sysconfdir}/crypto-policies/back-ends/gnutls28.config \
	   --with-default-trust-store-pkcs11="pkcs11:model=p11-kit-trust;manufacturer=PKCS%2311%20Kit" \
           --disable-guile \
           --disable-dane \
           --disable-rpath
make %{?_smp_mflags} V=1

%install
make install DESTDIR=$RPM_BUILD_ROOT

# remove files that shouldn't go in the compat package
rm -rf $RPM_BUILD_ROOT%{_bindir}
rm -rf $RPM_BUILD_ROOT%{_includedir}
rm -rf $RPM_BUILD_ROOT%{_libdir}/*.la
rm -rf $RPM_BUILD_ROOT%{_libdir}/*.so
rm -rf $RPM_BUILD_ROOT%{_libdir}/libgnutls-dane.so*
rm -rf $RPM_BUILD_ROOT%{_libdir}/libgnutlsxx.so*
rm -rf $RPM_BUILD_ROOT%{_libdir}/pkgconfig/
rm -rf $RPM_BUILD_ROOT%{_datadir}

%check
make check %{?_smp_mflags}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%{_libdir}/libgnutls.so.28*
%license COPYING COPYING.LESSER

%changelog
* Mon Feb 15 2016 Nikos Mavrogiannopoulos <nmav@redhat.com> - 3.3.21-1
- new upstream release

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Jan 11 2016 Nikos Mavrogiannopoulos <nmav@redhat.com> - 3.3.20-1
- new upstream release

* Wed Nov  4 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 3.3.18-2
- re-added crypto policies support using a special config file (#1277790)

* Thu Oct  8 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 3.3.18-1
- updated package to 3.3.18
- don't read the default priorities file; it is not guarranteed we can parse it (#1269453)

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.15-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May  4 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 3.3.15-1
- updated package and make it depend on nettle 3.1.1

* Tue Apr 28 2015 Kalev Lember <kalevlember@gmail.com> - 3.3.14-1
- gnutls ABI version 28 compatibility package (#1215997)
